@@ -114,10 +114,10 @@ use JSON;
 use LWP::UserAgent;
 use Scalar::Util 1.10 qw{ blessed looks_like_number };
 
-our $VERSION = '0.100_02';
+our $VERSION = '0.101_01';
 
 use constant BEST_DATA_SET => -1;
-use constant USGS_URL => 'http://ned.usgs.gov/epqs/pqs.php';
+use constant USGS_URL => 'http://nationalmap.gov/epqs/pqs.php';
 
 my $using_time_hires;
 {
@@ -953,7 +953,7 @@ Thomas R. Wyant, III; F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2014 Thomas R. Wyant, III
+Copyright (C) 2008-2015 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
